==> tine20-allinone_2019.12.5.tar.bz2: Admin/js/Admin-lang-en_AU-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: English (Australia) (http://www.transifex.com/tine20/tine20/language/en_AU/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: en_AU\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "User, Users"
: [
  "User"
 ,"Users"

]
, "Groups"
: "Groups"

, "Roles"
: "Roles"

, "Applications"
: "Applications"

, "Containers"
: "Containers"

, "Shared Tags"
: "Shared Tags"

, "Customfields"
: "Customfields"

, "Computers"
: "Computers"

, "Access Log, Access Logs"
: [
  "Access Log"
 ,"Access Logs"

]
, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "Admin"
: "Admin"

, "Refresh"
: ""

, "Name"
: "Name"

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Computer, Computers"
: [
  "Computer"
 ,"Computers"

]
, "Default Addressbook for new contacts and groups"
: "Default Addressbook for new contacts and groups"

, "Group, Groups"
: [
  "Group"
 ,"Groups"

]
, "Application, Applications"
: [
  "Application"
 ,"Applications"

]
, "Config, Configs"
: [
  ""
 ,""

]
, "Configs"
: ""

, "Please wait"
: "Please wait"

, "Updating Memberships"
: "Updating Memberships"

, "Failed"
: "Failed"

, "Could not save group."
: "Could not save group."

, "Errors"
: "Errors"

, "Please fix the errors noted."
: "Please fix the errors noted."

, "Group Name"
: "Group Name"

, "Description"
: "Description"

, "Visibility"
: "Visibility"

, "Display in addressbook"
: "Display in addressbook"

, "Hide from addressbook"
: "Hide from addressbook"

, "Saved in Addressbook"
: "Saved in Addressbook"

, "Group Members"
: "Group Members"

, "Transferring {0}..."
: "Transferring {0}..."

, "Add new group"
: "Add new group"

, "Edit Group \"{0}\""
: "Edit Group \"{0}\""

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: "{0} Settings"

, "enable application"
: "enable application"

, "disable application"
: "disable application"

, "settings"
: "settings"

, "Search:"
: "Search:"

, "disabled"
: "disabled"

, "enabled"
: "enabled"

, "unknown status ({0})"
: "unknown status ({0})"

, "Displaying application {0} - {1} of {2}"
: "Displaying application {0} - {1} of {2}"

, "No applications to display"
: "No applications to display"

, "Order"
: "Order"

, "Status"
: "Status"

, "Version"
: "Version"

, "Confirm"
: "Confirm"

, "Do you really want to delete the selected groups?"
: "Do you really want to delete the selected groups?"

, "Deleting group(s)..."
: "Deleting group(s)..."

, "Some error occurred while trying to delete the group."
: "Some error occurred while trying to delete the group."

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "Displaying groups {0} - {1} of {2}"

, "No groups to display"
: "No groups to display"

, "ID"
: "ID"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Computer Name"
: "Computer Name"

, "IP Address"
: "IP Address"

, "Login Time"
: "Login Time"

, "Logout Time"
: "Logout Time"

, "Client Type"
: "Client Type"

, "Session ID"
: "Session ID"

, "Login Name"
: "Login Name"

, "Result"
: "Result"

, "user blocked"
: "user blocked"

, "password expired"
: "password expired"

, "user disabled"
: "user disabled"

, "invalid password"
: "invalid password"

, "ambiguous username"
: "ambiguous username"

, "user not found"
: "user not found"

, "failure"
: "failure"

, "success"
: "success"

, "Could not save role."
: "Could not save role."

, "Deleting role..."
: "Deleting role..."

, "Some error occurred while trying to delete the role."
: "Some error occurred while trying to delete the role."

, "Rights"
: "Rights"

, "Members"
: "Members"

, "Role Name"
: "Role Name"

, "Role"
: "Role"

, "Add New Role"
: "Add New Role"

, "Edit Role \"{0}\""
: "Edit Role \"{0}\""

, "Container Name"
: "Container Name"

, "Type"
: "Type"

, "Container Order"
: ""

, "Container, Containers"
: [
  "Container"
 ,"Containers"

]
, "Model"
: "Model"

, "personal"
: "personal"

, "shared"
: "shared"

, "Color"
: "Color"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Note for Owner"

, "Do you really want to delete the selected roles?"
: "Do you really want to delete the selected roles?"

, "Deleting role(s)..."
: "Deleting role(s)..."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: "Displaying roles {0} - {1} of {2}"

, "No roles to display"
: "No roles to display"

, "Do you really want to delete the selected tags?"
: "Do you really want to delete the selected tags?"

, "Deleting tag(s)..."
: "Deleting tag(s)..."

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: "Displaying tags {0} - {1} of {2}"

, "No tags to display"
: "No tags to display"

, "Usage:&#160;"
: "Usage:&#160;"

, "Label"
: "Label"

, "Value"
: "Value"

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Customfield, Customfields"
: [
  "Customfield"
 ,"Customfields"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Please configure store for this field type"
: "Please configure store for this field type"

, "Record Class"
: "Record Class"

, "Given record class not found"
: "Given record class not found"

, "Cancel"
: "Cancel"

, "OK"
: "OK"

, "Configure store"
: "Configure store"

, "Custom field definition"
: "Custom field definition"

, "Text"
: "Text"

, "Textarea"
: ""

, "Number"
: "Number"

, "Date"
: "Date"

, "DateTime"
: "DateTime"

, "Time"
: "Time"

, "Boolean"
: "Boolean"

, "Search Combo"
: "Search Combo"

, "Key Field"
: "Key Field"

, "Record"
: "Record"

, "Record List"
: ""

, "Length"
: "Length"

, "Required"
: ""

, "Custom field additional properties"
: "Custom field additional properties"

, "Tab Panel"
: ""

, "Customfield already exists. Please choose another name."
: "Customfield already exists. Please choose another name."

, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "Login name"
: ""

, "Last name"
: "Last name"

, "First name"
: "First name"

, "Email"
: "Email"

, "Email usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: "OpenID"

, "Last login at"
: "Last login at"

, "Last login from"
: "Last login from"

, "Password changed"
: "Password changed"

, "Expires"
: "Expires"

, "Set new password"
: "Set new password"

, "Please enter the new password:"
: "Please enter the new password:"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Users"
: "Users"

, "Samba User, Samba Users"
: [
  "Samba User"
 ,"Samba Users"

]
, "Email User, Email Users"
: [
  "Email User"
 ,"Email Users"

]
, "Domain is not allowed. Check your SMTP domain configuration."
: "Domain is not allowed. Check your SMTP domain configuration."

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Passwords do not match!"

, "Passwords match!"
: "Passwords match!"

, "Primary group"
: "Primary group"

, "Unix"
: "Unix"

, "Home Directory"
: "Home Directory"

, "Login Shell"
: "Login Shell"

, "Windows"
: "Windows"

, "Home Drive"
: "Home Drive"

, "Logon Time"
: "Logon Time"

, "never logged in"
: "never logged in"

, "Home Path"
: "Home Path"

, "Logoff Time"
: "Logoff Time"

, "never logged off"
: "never logged off"

, "Profile Path"
: "Profile Path"

, "Password Last Set"
: "Password Last Set"

, "never"
: "never"

, "Logon Script"
: "Logon Script"

, "Password Can Change"
: "Password Can Change"

, "not set"
: "not set"

, "Password Must Change"
: "Password Must Change"

, "Kick Off Time"
: "Kick Off Time"

, "Filesystem Quota"
: ""

, "Quota"
: "Quota"

, "no quota set"
: "no quota set"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Current Mailbox size"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "Current Sieve size"

, "Information"
: "Information"

, "Last Login"
: "Last Login"

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Email Alias"
: "Email Alias"

, "Add an alias address..."
: "Add an alias address..."

, "Forwarding to self"
: ""

, "You are not allowed to set a forward email address that is identical to the users primary email or one of his aliases."
: ""

, "Email Forward"
: "Email Forward"

, "Add a forward address..."
: "Add a forward address..."

, "Forward Only"
: "Forward Only"

, "Password confirmation"
: "Password confirmation"

, "Repeat password"
: "Repeat password"

, "Ok"
: "Ok"

, "Account"
: "Account"

, "Password"
: "Password"

, "expired"
: "expired"

, "blocked"
: "blocked"

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "don't know"
: "don't know"

, "Password set"
: "Password set"

, "User groups"
: "User groups"

, "User roles"
: "User roles"

, "Fileserver"
: "Fileserver"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Updating Tag"
: "Updating Tag"

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: "Allowed Contexts"

, "Context"
: "Context"

, "Account Rights"
: "Account Rights"

, "View"
: "View"

, "Use"
: "Use"

, "Tag Name"
: "Tag Name"

, "Tag"
: "Tag"

, "Add New Tag"
: "Add New Tag"

, "Edit Tag \"{0}\""
: "Edit Tag \"{0}\""

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "manage access log"
: "manage access log"

, "delete access log entries"
: "delete access log entries"

, "manage accounts"
: "manage accounts"

, "add and edit users and groups, add group members, change user passwords"
: "add and edit users and groups, add group members, change user passwords"

, "manage applications"
: "manage applications"

, "enable and disable applications, edit application settings"
: "enable and disable applications, edit application settings"

, "manage roles"
: "manage roles"

, "add and edit roles, add new members to roles, add application rights to roles"
: "add and edit roles, add new members to roles, add application rights to roles"

, "manage shared tags"
: "manage shared tags"

, "add, delete and edit shared tags"
: "add, delete and edit shared tags"

, "manage computers"
: "manage computers"

, "add, delete and edit (samba) computers"
: "add, delete and edit (samba) computers"

, "manage containers"
: "manage containers"

, "add, delete and edit containers and manage container grants"
: "add, delete and edit containers and manage container grants"

, "manage customfields"
: ""

, "add and edit customfields"
: ""

, "view access log"
: "view access log"

, "view access log list"
: "view access log list"

, "view accounts"
: "view accounts"

, "view accounts list and details"
: "view accounts list and details"

, "view applications"
: "view applications"

, "view applications list and details"
: "view applications list and details"

, "view roles"
: "view roles"

, "view roles list and details"
: "view roles list and details"

, "view computers"
: "view computers"

, "view computers list and details"
: "view computers list and details"

, "view containers"
: "view containers"

, "view personal and shared containers"
: "view personal and shared containers"

, "view customfields"
: ""

, "view customfields list"
: ""

, "view serverinfo"
: ""

, "view serverinfo list"
: ""

, "view quota usage"
: ""

, "Your container has been changed"
: "Your container has been changed"

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Your container has been changed by %1$s %2$sNote: %3$s"

, "Could not save tag without (view-)rights"
: ""

, "User"
: "User"

, "Access Log"
: "Access Log"

, "Computer"
: "Computer"

, "Group"
: "Group"

, "Application"
: "Application"

, "Config"
: ""

, "Container"
: "Container"

, "Customfield"
: "Customfield"

, "Samba User"
: "Samba User"

, "Email User"
: "Email User"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Admin/js/Admin-lang-en_AU-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: English (Australia) (http://www.transifex.com/tine20/tine20/language/en_AU/)\nLanguage: en_AU\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: "{0} Settings"

, "Search:"
: "Search:"

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Displaying application {0} - {1} of {2}"

, "No applications to display"
: "No applications to display"

, "Order"
: "Order"

, "Name"
: "Name"

, "Status"
: "Status"

, "Version"
: "Version"

, "Confirm"
: "Confirm"

, "Do you really want to delete the selected groups?"
: "Do you really want to delete the selected groups?"

, "Deleting group(s)..."
: "Deleting group(s)..."

, "Failed"
: "Failed"

, "Some error occurred while trying to delete the group."
: "Some error occurred while trying to delete the group."

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "Displaying groups {0} - {1} of {2}"

, "No groups to display"
: "No groups to display"

, "ID"
: "ID"

, "E-mail"
: ""

, "Description"
: "Description"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: "Errors"

, "Please configure store for this field type"
: "Please configure store for this field type"

, "Application, Applications"
: [
  "Application"
 ,"Applications"

]
, "Record Class"
: "Record Class"

, "Given record class not found"
: "Given record class not found"

, "Cancel"
: "Cancel"

, "OK"
: "OK"

, "Configure store"
: "Configure store"

, "Model"
: "Model"

, "Custom field definition"
: "Custom field definition"

, "Text"
: "Text"

, "Textarea"
: ""

, "Number"
: "Number"

, "Date"
: "Date"

, "DateTime"
: "DateTime"

, "Time"
: "Time"

, "Boolean"
: "Boolean"

, "Search Combo"
: "Search Combo"

, "Key Field"
: "Key Field"

, "Record"
: "Record"

, "Record List"
: ""

, "Type"
: "Type"

, "Label"
: "Label"

, "Length"
: "Length"

, "Required"
: ""

, "Custom field additional properties"
: "Custom field additional properties"

, "Tab Panel"
: ""

, "Group, Groups"
: [
  "Group"
 ,"Groups"

]
, "Customfield already exists. Please choose another name."
: "Customfield already exists. Please choose another name."

, "Customfield, Customfields"
: [
  "Customfield"
 ,"Customfields"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""
 ,""

]
, "Value"
: "Value"

, "Default ({0})"
: ""

, "Computer Name"
: "Computer Name"

, "Default Addressbook for new contacts and groups"
: "Default Addressbook for new contacts and groups"

, "Please wait"
: "Please wait"

, "Updating Tag"
: "Updating Tag"

, "Could not save tag ({0})"
: ""

, "Please fix the errors noted."
: "Please fix the errors noted."

, "Allowed Contexts"
: "Allowed Contexts"

, "Context"
: "Context"

, "Account Rights"
: "Account Rights"

, "View"
: "View"

, "Use"
: "Use"

, "Tag Name"
: "Tag Name"

, "Color"
: "Color"

, "Transferring {0}..."
: "Transferring {0}..."

, "Tag"
: "Tag"

, "Add New Tag"
: "Add New Tag"

, "Edit Tag \"{0}\""
: "Edit Tag \"{0}\""

, "Do you really want to delete the selected tags?"
: "Do you really want to delete the selected tags?"

, "Deleting tag(s)..."
: "Deleting tag(s)..."

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: "Displaying tags {0} - {1} of {2}"

, "No tags to display"
: "No tags to display"

, "Usage:&#160;"
: "Usage:&#160;"

, "Updating Memberships"
: "Updating Memberships"

, "Could not save role."
: "Could not save role."

, "Deleting role..."
: "Deleting role..."

, "Some error occurred while trying to delete the role."
: "Some error occurred while trying to delete the role."

, "Rights"
: "Rights"

, "Members"
: "Members"

, "Role Name"
: "Role Name"

, "Role"
: "Role"

, "Add New Role"
: "Add New Role"

, "Edit Role \"{0}\""
: "Edit Role \"{0}\""

, "Do you really want to delete the selected roles?"
: "Do you really want to delete the selected roles?"

, "Deleting role(s)..."
: "Deleting role(s)..."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: "Displaying roles {0} - {1} of {2}"

, "No roles to display"
: "No roles to display"

, "Access Log, Access Logs"
: [
  "Access Log"
 ,"Access Logs"

]
, "Groups"
: "Groups"

, "Applications"
: "Applications"

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: "Domain is not allowed. Check your SMTP domain configuration."

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Passwords do not match!"

, "Passwords match!"
: "Passwords match!"

, "Primary group"
: "Primary group"

, "Unix"
: "Unix"

, "Home Directory"
: "Home Directory"

, "Login Shell"
: "Login Shell"

, "Windows"
: "Windows"

, "Home Drive"
: "Home Drive"

, "Login Time"
: "Login Time"

, "never logged in"
: "never logged in"

, "Home Path"
: "Home Path"

, "Logout Time"
: "Logout Time"

, "never logged off"
: "never logged off"

, "Profile Path"
: "Profile Path"

, "Password Last Set"
: "Password Last Set"

, "never"
: "never"

, "Logon Script"
: "Logon Script"

, "Password Can Change"
: "Password Can Change"

, "not set"
: "not set"

, "Password Must Change"
: "Password Must Change"

, "Kick Off Time"
: "Kick Off Time"

, "Filesystem Quota"
: ""

, "Quota"
: "Quota"

, "no quota set"
: "no quota set"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Current Mailbox size"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "Current Sieve size"

, "Information"
: "Information"

, "Last Login"
: "Last Login"

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: "Add an alias address..."

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: "Forward Only"

, "Password confirmation"
: "Password confirmation"

, "Repeat password"
: "Repeat password"

, "Ok"
: "Ok"

, "Account"
: "Account"

, "First name"
: "First name"

, "Last name"
: "Last name"

, "Login name"
: ""

, "Password"
: "Password"

, "OpenID"
: "OpenID"

, "enabled"
: "enabled"

, "disabled"
: "disabled"

, "expired"
: "expired"

, "blocked"
: "blocked"

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "Expires"
: "Expires"

, "Visibility"
: "Visibility"

, "Display in addressbook"
: "Display in addressbook"

, "Hide from addressbook"
: "Hide from addressbook"

, "Saved in Addressbook"
: "Saved in Addressbook"

, "Last login at"
: "Last login at"

, "don't know"
: "don't know"

, "Last login from"
: "Last login from"

, "Password set"
: "Password set"

, "User groups"
: "User groups"

, "User roles"
: "User roles"

, "Fileserver"
: "Fileserver"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "User, Users"
: [
  "User"
 ,"Users"

]
, "Users"
: "Users"

, "Samba User, Samba Users"
: [
  "Samba User"
 ,"Samba Users"

]
, "Email User, Email Users"
: [
  "Email User"
 ,"Email Users"

]
, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: "Password changed"

, "Set new password"
: "Set new password"

, "Please enter the new password:"
: "Please enter the new password:"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: "Group Name"

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Group Members"

, "personal"
: "personal"

, "shared"
: "shared"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Note for Owner"

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  "Container"
 ,"Containers"

]
, "Container Name"
: "Container Name"

, "Container Order"
: ""

, "Computer, Computers"
: [
  "Computer"
 ,"Computers"

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: "Roles"

, "Containers"
: "Containers"

, "Shared Tags"
: "Shared Tags"

, "Customfields"
: "Customfields"

, "Computers"
: "Computers"

, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Admin"
: "Admin"

, "Refresh"
: ""

, "Feature is disabled by configuration."
: ""

, "IP Address"
: "IP Address"

, "Client Type"
: "Client Type"

, "Session ID"
: "Session ID"

, "Login Name"
: "Login Name"

, "Result"
: "Result"

, "user blocked"
: "user blocked"

, "password expired"
: "password expired"

, "user disabled"
: "user disabled"

, "invalid password"
: "invalid password"

, "ambiguous username"
: "ambiguous username"

, "user not found"
: "user not found"

, "failure"
: "failure"

, "success"
: "success"

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: "Your container has been changed"

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Your container has been changed by %1$s %2$sNote: %3$s"

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""








































, "Application"
: "Application"

, "Group"
: "Group"

, "Customfield"
: "Customfield"

, "Config"
: ""

, "Access Log"
: "Access Log"

, "User"
: "User"

, "Samba User"
: "Samba User"

, "Email User"
: "Email User"

, "Container"
: "Container"

, "Computer"
: "Computer"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
